==> substance_4.1.orig.tar.gz: substance-4.1.orig/src/org/jvnet/substance/SubstanceSeparatorUI.java <==
/*
 * Copyright (c) 2005-2007 Substance Kirill Grouchnikov. All Rights Reserved.
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * 
 *  o Redistributions of source code must retain the above copyright notice, 
 *    this list of conditions and the following disclaimer. 
 *     
 *  o Redistributions in binary form must reproduce the above copyright notice, 
 *    this list of conditions and the following disclaimer in the documentation 
 *    and/or other materials provided with the distribution. 
 *     
 *  o Neither the name of Substance Kirill Grouchnikov nor the names of 
 *    its contributors may be used to endorse or promote products derived 
 *    from this software without specific prior written permission. 
 *     
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, 
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR 
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR 
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, 
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, 
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; 
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE 
 * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, 
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 
 */
package org.jvnet.substance;

import java.awt.*;

import javax.swing.*;
import javax.swing.plaf.ComponentUI;
import javax.swing.plaf.basic.BasicSeparatorUI;

import org.jvnet.lafwidget.layout.TransitionLayout;
import org.jvnet.substance.color.ColorScheme;
import org.jvnet.substance.theme.SubstanceTheme;
import org.jvnet.substance.title.SubstanceHeaderPainter;
import org.jvnet.substance.title.SubstanceTitlePainter;
import org.jvnet.substance.utils.SubstanceCoreUtilities;
import org.jvnet.substance.utils.SubstanceSizeUtils;
import org.jvnet.substance.utils.SubstanceConstants.MenuGutterFillKind;
import org.jvnet.substance.utils.menu.MenuUtilities;

/**
 * UI for separators in <b>Substance</b> look and feel.
 * 
 * @author Kirill Grouchnikov
 */
public class SubstanceSeparatorUI extends BasicSeparatorUI {
	public static ComponentUI createUI(JComponent c) {
		return new SubstanceSeparatorUI();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see javax.swing.plaf.basic.BasicSeparatorUI#paint(java.awt.Graphics,
	 *      javax.swing.JComponent)
	 */
	@Override
	public void paint(Graphics g, JComponent c) {
		Graphics2D graphics = (Graphics2D) g.create();
		SubstanceTitlePainter titlePainter = SubstanceCoreUtilities
				.getTitlePainter(SwingUtilities.getRootPane(c));
		boolean shouldUseHeaderPainter = titlePainter instanceof SubstanceHeaderPainter;
		if (titlePainter instanceof SubstanceHeaderPainter)
			shouldUseHeaderPainter = ((SubstanceHeaderPainter) titlePainter)
					.isPaintingContainer(c.getParent());
		SubstanceTheme theme = shouldUseHeaderPainter ? SubstanceLookAndFeel
				.getTheme().getActiveTitlePaneTheme() : SubstanceLookAndFeel
				.getTheme();
		// special case for skins such as BusinessBlackSteel, which use
		// dark theme for header (title pane + menus) - using such a dark
		// theme on a separator is not good, since all the separator "lives"
		// among controls that are assuming a non-dark theme.
		if (SubstanceCoreUtilities.isThemeDark(theme) != SubstanceCoreUtilities
				.isThemeDark(SubstanceLookAndFeel.getTheme())) {
			theme = SubstanceLookAndFeel.getTheme().getDefaultTheme();
		}
		boolean isDark = SubstanceCoreUtilities.isThemeDark(theme
				.getActiveTheme());
		ColorScheme colorScheme = (shouldUseHeaderPainter || isDark) ? theme
				.getActiveTheme().getColorScheme() : theme.getDefaultTheme()
				.getColorScheme();
		try {
			Component parent = c.getParent();
			if (!(parent instanceof JPopupMenu)) {
				// SubstanceTheme theme = SubstanceLookAndFeel.getTheme();
				// boolean isDark = SubstanceCoreUtilities.isThemeDark(theme
				// .getActiveTheme());
				// ColorScheme colorScheme = isDark ? theme.getActiveTheme()
				// .getColorScheme() : theme.getDefaultTheme()
				// .getColorScheme();

				SubstanceCoreUtilities.paintSeparator(c, graphics, colorScheme,
						isDark, c.getWidth(), c.getHeight(), ((JSeparator) c)
								.getOrientation());
				return;
			}

			int xOffset = MenuUtilities.getTextOffset(graphics, parent);

			Dimension s = c.getSize();
			int startX = 0;
			int width = s.width;
			if (parent.getComponentOrientation().isLeftToRight()) {
				MenuGutterFillKind fillKind = SubstanceCoreUtilities
						.getMenuGutterFillKind();
				if (fillKind != MenuGutterFillKind.NONE) {
					ColorScheme scheme = SubstanceCoreUtilities
							.getActiveScheme(parent);
					Color leftColor = ((fillKind == MenuGutterFillKind.SOFT_FILL) || (fillKind == MenuGutterFillKind.HARD)) ? scheme
							.getUltraLightColor()
							: scheme.getLightColor();
					Color rightColor = ((fillKind == MenuGutterFillKind.SOFT_FILL) || (fillKind == MenuGutterFillKind.SOFT)) ? scheme
							.getUltraLightColor()
							: scheme.getLightColor();
					GradientPaint gp = new GradientPaint(0, 0, leftColor,
							xOffset, 0, rightColor);

					graphics.setComposite(TransitionLayout.getAlphaComposite(
							parent, 0.7f, g));
					graphics.setPaint(gp);
					graphics.fillRect(0, 0, xOffset - 2, c.getHeight());
				}
				// graphics.setComposite(TransitionLayout
				// .getAlphaComposite(parent));
				//
				// graphics.setColor(c.getForeground());
				// graphics.drawLine(xOffset, 0, s.width, 0);
				//
				// graphics.setColor(c.getBackground());
				// graphics.drawLine(xOffset, 1, s.width, 1);
				startX = xOffset - 2;
				width = s.width - startX;
			} else {
				// fix for defect 125 - support of RTL menus
				MenuGutterFillKind fillKind = SubstanceCoreUtilities
						.getMenuGutterFillKind();
				if (fillKind != MenuGutterFillKind.NONE) {
					ColorScheme scheme = SubstanceCoreUtilities
							.getActiveScheme(parent);
					Color leftColor = ((fillKind == MenuGutterFillKind.HARD_FILL) || (fillKind == MenuGutterFillKind.HARD)) ? scheme
							.getLightColor()
							: scheme.getUltraLightColor();
					Color rightColor = ((fillKind == MenuGutterFillKind.HARD_FILL) || (fillKind == MenuGutterFillKind.SOFT)) ? scheme
							.getLightColor()
							: scheme.getUltraLightColor();
					GradientPaint gp = new GradientPaint(s.width - xOffset, 0,
							leftColor, s.width, 0, rightColor);

					graphics.setComposite(TransitionLayout.getAlphaComposite(
							parent, 0.7f, g));
					graphics.setPaint(gp);
					graphics.fillRect(s.width - xOffset - 2, 0, s.width, c
							.getHeight());
				}
				// graphics.setComposite(TransitionLayout
				// .getAlphaComposite(parent));

				// graphics.setColor(c.getForeground());
				// graphics.drawLine(0, 0, s.width - xOffset - 4, 0);
				//
				// graphics.setColor(c.getBackground());
				// graphics.drawLine(0, 1, s.width - xOffset - 4, 1);
				startX = 0;
				width = s.width - xOffset - 4;
			}
			graphics.translate(startX, 0);
			graphics.setComposite(TransitionLayout.getAlphaComposite(parent));
			SubstanceCoreUtilities.paintSeparator(c, graphics, colorScheme,
					isDark, width, s.height, ((JSeparator) c).getOrientation(),
					true, 2);
		} finally {
			graphics.dispose();
		}
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see javax.swing.plaf.basic.BasicSeparatorUI#getPreferredSize(javax.swing.JComponent)
	 */
	@Override
	public Dimension getPreferredSize(JComponent c) {
		float borderStrokeWidth = SubstanceSizeUtils
				.getBorderStrokeWidth(SubstanceSizeUtils
						.getComponentFontSize(c));
		int prefSize = (int) (Math.ceil(2.0 * borderStrokeWidth));
		if (((JSeparator) c).getOrientation() == SwingConstants.VERTICAL)
			return new Dimension(prefSize, 0);
		else
			return new Dimension(0, prefSize);
	}
}

==> substance_4.3.11.orig.tar.gz: substance-4.3.11.orig/src/org/jvnet/substance/SubstanceSeparatorUI.java <==
/*
 * Copyright (c) 2005-2008 Substance Kirill Grouchnikov. All Rights Reserved.
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * 
 *  o Redistributions of source code must retain the above copyright notice, 
 *    this list of conditions and the following disclaimer. 
 *     
 *  o Redistributions in binary form must reproduce the above copyright notice, 
 *    this list of conditions and the following disclaimer in the documentation 
 *    and/or other materials provided with the distribution. 
 *     
 *  o Neither the name of Substance Kirill Grouchnikov nor the names of 
 *    its contributors may be used to endorse or promote products derived 
 *    from this software without specific prior written permission. 
 *     
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, 
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR 
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR 
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, 
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, 
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; 
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE 
 * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, 
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 
 */
package org.jvnet.substance;

import java.awt.*;

import javax.swing.*;
import javax.swing.plaf.ComponentUI;
import javax.swing.plaf.basic.BasicSeparatorUI;

import org.jvnet.lafwidget.layout.TransitionLayout;
import org.jvnet.substance.color.ColorScheme;
import org.jvnet.substance.theme.SubstanceTheme;
import org.jvnet.substance.utils.*;
import org.jvnet.substance.utils.SubstanceConstants.MenuGutterFillKind;
import org.jvnet.substance.utils.menu.MenuUtilities;

/**
 * UI for separators in <b>Substance</b> look and feel.
 * 
 * @author Kirill Grouchnikov
 */
public class SubstanceSeparatorUI extends BasicSeparatorUI {
	public static ComponentUI createUI(JComponent c) {
		return new SubstanceSeparatorUI();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see javax.swing.plaf.basic.BasicSeparatorUI#paint(java.awt.Graphics,
	 *      javax.swing.JComponent)
	 */
	@Override
	public void paint(Graphics g, JComponent c) {
		Graphics2D graphics = (Graphics2D) g.create();
		SubstanceTheme theme = SubstanceThemeUtilities.getTheme(c)
				.getDefaultTheme();
		ColorScheme colorScheme = theme.getColorScheme();

		try {
			Component parent = c.getParent();
			if (!(parent instanceof JPopupMenu)) {
				SubstanceCoreUtilities.paintSeparator(c, graphics, colorScheme,
						SubstanceCoreUtilities.isThemeDark(theme),
						c.getWidth(), c.getHeight(), ((JSeparator) c)
								.getOrientation());
				return;
			}

			int xOffset = MenuUtilities.getTextOffset(c, parent);

			Dimension s = c.getSize();
			int startX = 0;
			int width = s.width;
			if (parent.getComponentOrientation().isLeftToRight()) {
				MenuGutterFillKind fillKind = SubstanceCoreUtilities
						.getMenuGutterFillKind();
				if (fillKind != MenuGutterFillKind.NONE) {
					ColorScheme scheme = SubstanceThemeUtilities.getTheme(
							parent, ComponentState.DEFAULT).getColorScheme();
					Color leftColor = ((fillKind == MenuGutterFillKind.SOFT_FILL) || (fillKind == MenuGutterFillKind.HARD)) ? scheme
							.getUltraLightColor()
							: scheme.getLightColor();
					Color rightColor = ((fillKind == MenuGutterFillKind.SOFT_FILL) || (fillKind == MenuGutterFillKind.SOFT)) ? scheme
							.getUltraLightColor()
							: scheme.getLightColor();
					GradientPaint gp = new GradientPaint(0, 0, leftColor,
							xOffset, 0, rightColor);

					graphics.setComposite(TransitionLayout.getAlphaComposite(
							parent, 0.7f, g));
					graphics.setPaint(gp);
					graphics.fillRect(0, 0, xOffset - 2, c.getHeight());
				}
				// graphics.setComposite(TransitionLayout
				// .getAlphaComposite(parent));
				//
				// graphics.setColor(c.getForeground());
				// graphics.drawLine(xOffset, 0, s.width, 0);
				//
				// graphics.setColor(c.getBackground());
				// graphics.drawLine(xOffset, 1, s.width, 1);
				startX = xOffset - 2;
				width = s.width - startX;
			} else {
				// fix for defect 125 - support of RTL menus
				MenuGutterFillKind fillKind = SubstanceCoreUtilities
						.getMenuGutterFillKind();
				if (fillKind != MenuGutterFillKind.NONE) {
					ColorScheme scheme = SubstanceThemeUtilities.getTheme(
							parent, ComponentState.DEFAULT).getColorScheme();
					Color leftColor = ((fillKind == MenuGutterFillKind.HARD_FILL) || (fillKind == MenuGutterFillKind.HARD)) ? scheme
							.getLightColor()
							: scheme.getUltraLightColor();
					Color rightColor = ((fillKind == MenuGutterFillKind.HARD_FILL) || (fillKind == MenuGutterFillKind.SOFT)) ? scheme
							.getLightColor()
							: scheme.getUltraLightColor();
					GradientPaint gp = new GradientPaint(xOffset, 0, leftColor,
							s.width, 0, rightColor);

					graphics.setComposite(TransitionLayout.getAlphaComposite(
							parent, 0.7f, g));
					graphics.setPaint(gp);
					graphics.fillRect(xOffset - 2, 0, s.width, c.getHeight());
				}
				// graphics.setComposite(TransitionLayout
				// .getAlphaComposite(parent));

				// graphics.setColor(c.getForeground());
				// graphics.drawLine(0, 0, s.width - xOffset - 4, 0);
				//
				// graphics.setColor(c.getBackground());
				// graphics.drawLine(0, 1, s.width - xOffset - 4, 1);
				startX = 0;
				width = xOffset - 4;
			}
			graphics.translate(startX, 0);
			graphics.setComposite(TransitionLayout.getAlphaComposite(parent));
			SubstanceCoreUtilities.paintSeparator(c, graphics, colorScheme,
					SubstanceCoreUtilities.isThemeDark(theme), width, s.height,
					((JSeparator) c).getOrientation(), true, 2);
		} finally {
			graphics.dispose();
		}
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see javax.swing.plaf.basic.BasicSeparatorUI#getPreferredSize(javax.swing.JComponent)
	 */
	@Override
	public Dimension getPreferredSize(JComponent c) {
		float borderStrokeWidth = SubstanceSizeUtils
				.getBorderStrokeWidth(SubstanceSizeUtils
						.getComponentFontSize(c));
		int prefSize = (int) (Math.ceil(2.0 * borderStrokeWidth));
		if (((JSeparator) c).getOrientation() == SwingConstants.VERTICAL)
			return new Dimension(prefSize, 0);
		else
			return new Dimension(0, prefSize);
	}
}
